Extract real data for plotting
Value
A data frame of observed values for plotting, or NULL when the
requested quantity is not present in the real-data inputs.
Examples
# See ?run_backcalc for a full end-to-end workflow.
invisible(NULL)
Extract real data for plotting
A data frame of observed values for plotting, or NULL when the
requested quantity is not present in the real-data inputs.
# See ?run_backcalc for a full end-to-end workflow.
invisible(NULL)