Remodel the simulated diagnosis data for fitting a different model type.
Source:R/sim_remodel.R
sim_remodel.RdThis function takes the output from simulate_diagnoses() and
remodels the data to be suitable for fitting a different model type
(e.g., from RITA to CD4-only model).
Arguments
- sim_diags
A list output from
simulate_diagnoses().- rita
Logical; if
TRUE, remodels the data for fitting an RITA model; ifFALSE, remodels the data for fitting a CD4-only model.
Examples
#' # Simulate diagnoses data using RITA model
sim_diags <- simulate_diagnoses(nquar = 60, rita = TRUE, sim_seed = 123)
# Remodel data for fitting CD4-only model
remodeled_data <- sim_remodel(sim_diags, rita = FALSE)